@@ -785,12 +785,12 @@ class Data(ContentCollection):
                         rnames[new]=self.rnames[old]
         if self.coords is not None:
             if row_ids is None:
-                coords = self.coords.copy()
+                coords = [list(self.coords[i])  for i in range(len(self.coords))]
             else:
                 maps_to = numpy.array([0 for i in range(N)])
                 for old, news in row_ids.items():
                     maps_to[news] = old
-                coords = self.coords[:,maps_to]
+                coords = [[self.coords[i][j] for j in maps_to] for i in range(len(self.coords))]
 
         cols = [[],[]]
         for side in [0,1]:
@@ -1497,7 +1497,8 @@ def parseDNCFromCSVData(csv_data, single_dataset=False):
     if csv_data.get("coord", None) is not None:
         try:
             tmp = list(zip(*csv_data["coord"]))
-            coords = numpy.array([tmp[1], tmp[0]], dtype=object)
+            coords = [tmp[1], tmp[0]]
+            # coords = numpy.array([tmp[1], tmp[0]], dtype=object)
         except Exception:
             coords = None
 
